@@ -4,8 +4,7 @@ import json
 
 from click.testing import CliRunner
 from honeybee.cli import viz, config
-from honeybee.cli.validate import validate_model, validate_model_basic, \
-    validate_model_geometry
+from honeybee.cli.validate import validate_model
 
 
 def test_viz():
@@ -30,23 +29,10 @@ def test_validate_model():
     if (sys.version_info >= (3, 7)):
         runner = CliRunner()
         result = runner.invoke(validate_model, [input_model])
+        print(result.output)
         assert result.exit_code == 0
         runner = CliRunner()
         result = runner.invoke(validate_model, [incorrect_input_model])
-        assert result.exit_code == 1
-
-
-def test_validate_model_basic():
-    input_model = './tests/json/single_family_home.hbjson'
-    if (sys.version_info >= (3, 7)):
-        runner = CliRunner()
-        result = runner.invoke(validate_model_basic, [input_model])
-        assert result.exit_code == 0
-
-
-def test_validate_model_geometry():
-    input_model = './tests/json/single_family_home.hbjson'
-    if (sys.version_info >= (3, 7)):
-        runner = CliRunner()
-        result = runner.invoke(validate_model_geometry, [input_model])
-        assert result.exit_code == 0
+        outp = result.output
+        assert 'Your Model is invalid for the following reasons' in outp
+        assert 'is not coplanar or fully bounded by its parent Face' in outp
